@@ -6,7 +6,7 @@ from cookiecutter.main import cookiecutter
 from service_buddy_too.ci import build_creator
 from service_buddy_too.service.service import Service
 from service_buddy_too.util import command_util
-
+from service_buddy_too.ci.build_creator import transform_location
 
 def _make_cookie_safe(service_definition):
     ret = {}
@@ -27,7 +27,7 @@ class CookeCutterProjectCreator(object):
             location = os.path.abspath(os.path.join(self.template_dir, template['location']))
         else:
             location = template['location']
-            location = build_creator.transform_location(location,template['type'])
+            location = transform_location(location,template['type'])
         extra_context = _make_cookie_safe(service_definition)
         if extra_config:
             extra_context.update(_make_cookie_safe(extra_config))
